#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              2.2.0.0
visibility:           public
id:                   lsp-2.2.0.0-CukKTvdVHsT6La4UfPeciM
key:                  lsp-2.2.0.0-CukKTvdVHsT6La4UfPeciM
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  36d6a79551b426a4ef856381b4801450
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Logging,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.2.0-FNuvH5SC6qmB6cafXuw33H:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Lens from lsp-types-2.0.2.0-FNuvH5SC6qmB6cafXuw33H:Language.LSP.Protocol.Lens,
    Language.LSP.Protocol.Message from lsp-types-2.0.2.0-FNuvH5SC6qmB6cafXuw33H:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.2.0-FNuvH5SC6qmB6cafXuw33H:Language.LSP.Protocol.Types,
    Language.LSP.Server, Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Control Language.LSP.Server.Core
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp
hs-libraries:         HSlsp-2.2.0.0-CukKTvdVHsT6La4UfPeciM
depends:
    aeson-2.2.1.0-5Fs1RaTLSq5BR7MHVVBomI
    async-2.2.5-H7c59317Mex2thAVLk9lLr
    attoparsec-0.14.4-3JRMoINo5azLplLZog31oy base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.6-AkooIvf8mcK9LdjX1Jp4hv
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-H6imxCsecEO4wNDTcxh8s7
    lens-5.3.3-HM6Af9M3fTq36dNEKh0mJU
    lens-aeson-1.2.3-Db9XAILOg2G1S90qcCUKAi
    lsp-types-2.0.2.0-FNuvH5SC6qmB6cafXuw33H mtl-2.3.1
    prettyprinter-1.7.1-Egfz8R6Hy2931hrqdwzdET
    random-1.2.1.3-AO52BSfFrAr3Koj1Kh0gOJ
    row-types-1.0.1.2-BY5NodVtOuaGZC1GkBhOaU
    sorted-list-0.2.3.1-J5JxONhusfXKMUxQHrKBvJ stm-2.5.1.0
    temporary-1.3-EYmqEqRrhqE9Wlj5grfccr text-2.0.2
    text-rope-0.3-8xVglbMqpqLHQ5seLdLoIT transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-KjVwmKBzsCnE6cNwSXaI5c
    uuid-1.3.16-AGFlUiV1obhI9fGx4AagUe

haddock-interfaces:   /usr/share/doc/haskell-lsp/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

